@@ -379,6 +379,35 @@ class Attendance(Base):
         return '{}: {} балл ({})'.format(self.student, self.grade, self.date)
 
 
+class EducLang(Base):
+    """
+    Модель "Язык обучения"
+    """
+    __tablename__ = 'univer_educ_lang'
+
+    # Идентификатор
+    id = Column('educ_lang_id', Integer, primary_key=True)
+
+    # Наименование
+    name_ru = Column('educ_lang_name_ru', String)
+    name_kz = Column('educ_lang_name_kz', String)
+    name_en = Column('educ_lang_name_en', String)
+
+    # Короткое наименование
+    short_name_ru = Column('educ_lang_short_name_ru', String)
+    short_name_kz = Column('educ_lang_short_name_kz', String)
+    short_name_en = Column('educ_lang_short_name_en', String)
+
+    # Статус
+    status = Column(Integer)
+
+    def __repr__(self):
+        return '<EducLang {}>'.format(self)
+
+    def __str__(self):
+        return self.name_ru
+
+
 class Group(Base):
     """
     Модель "Группа"
@@ -403,6 +432,10 @@ class Group(Base):
         'univer_lang_division.lang_division_id'))
     lang_division = relationship('LangDivision')
 
+    # Язык обучения
+    educ_lang_id = Column(ForeignKey('univer_educ_lang.educ_lang_id'))
+    educ_lang = relationship('EducLang')
+
     # Семестр повторного обучения
     retake_semester = Column('group_retake_semestr', Integer)
 
